==> gandalf_1.3.2.orig.tar.gz: gandalf/vision.h <==
#include <gandalf/vision/affine33_fit.h>
#include <gandalf/vision/camera_convert.h>
#include <gandalf/vision/camera_defs.h>
#include <gandalf/vision/camera_equidistant.h>
#include <gandalf/vision/camera_equi_solid_angle.h>
#include <gandalf/vision/cameraf_equidistant.h>
#include <gandalf/vision/cameraf_equi_solid_angle.h>
#include <gandalf/vision/cameraf.h>
#include <gandalf/vision/cameraf_linear.h>
#include <gandalf/vision/cameraf_radial_dist1.h>
#include <gandalf/vision/cameraf_radial_dist1_inv.h>
#include <gandalf/vision/cameraf_radial_dist2.h>
#include <gandalf/vision/cameraf_radial_dist3.h>
#include <gandalf/vision/cameraf_sine_law.h>
#include <gandalf/vision/cameraf_stereographic.h>
#include <gandalf/vision/cameraf_xy_dist4.h>
#include <gandalf/vision/camera.h>
#include <gandalf/vision/camera_linear.h>
#include <gandalf/vision/camera_radial_dist1.h>
#include <gandalf/vision/camera_radial_dist1_inv.h>
#include <gandalf/vision/camera_radial_dist2.h>
#include <gandalf/vision/camera_radial_dist3.h>
#include <gandalf/vision/camera_sine_law.h>
#include <gandalf/vision/camera_stereographic.h>
#include <gandalf/vision/camera_xy_dist4.h>
#include <gandalf/vision/canny_edge.h>
#include <gandalf/vision/convolve1D.h>
#include <gandalf/vision/corner_disp.h>
#include <gandalf/vision/corner_feature.h>
#include <gandalf/vision/edge_disp.h>
#include <gandalf/vision/edge_feature.h>
#include <gandalf/vision/essential.h>
#include <gandalf/vision/euclid3D.h>
#include <gandalf/vision/fast_hough_transform.h>
#include <gandalf/vision/fundamental.h>
#include <gandalf/vision/harris_corner.h>
#include <gandalf/vision/homog33_fit.h>
#include <gandalf/vision/homog34_fit.h>
#include <gandalf/vision/lev_marq.h>
#include <gandalf/vision/line_disp.h>
#include <gandalf/vision/line_feature.h>
#include <gandalf/vision/local_feature.h>
#include <gandalf/vision/mask1D.h>
#include <gandalf/vision/modified_fht2D.h>
#include <gandalf/vision/orthog_line.h>
#include <gandalf/vision/rotate3D.h>

==> gandalf_1.5.orig.tar.gz: gandalf/vision.h <==
#include <gandalf/vision/affine33_fit.h>
#include <gandalf/vision/camera_convert.h>
#include <gandalf/vision/camera_defs.h>
#include <gandalf/vision/camera_equidistant.h>
#include <gandalf/vision/camera_equi_solid_angle.h>
#include <gandalf/vision/cameraf_equidistant.h>
#include <gandalf/vision/cameraf_equi_solid_angle.h>
#include <gandalf/vision/cameraf.h>
#include <gandalf/vision/cameraf_linear.h>
#include <gandalf/vision/cameraf_radial_dist1.h>
#include <gandalf/vision/cameraf_radial_dist1_inv.h>
#include <gandalf/vision/cameraf_radial_dist2.h>
#include <gandalf/vision/cameraf_radial_dist3.h>
#include <gandalf/vision/cameraf_sine_law.h>
#include <gandalf/vision/cameraf_stereographic.h>
#include <gandalf/vision/cameraf_xy_dist4.h>
#include <gandalf/vision/camera.h>
#include <gandalf/vision/camera_linear.h>
#include <gandalf/vision/camera_radial_dist1.h>
#include <gandalf/vision/camera_radial_dist1_inv.h>
#include <gandalf/vision/camera_radial_dist2.h>
#include <gandalf/vision/camera_radial_dist3.h>
#include <gandalf/vision/camera_sine_law.h>
#include <gandalf/vision/camera_stereographic.h>
#include <gandalf/vision/camera_xy_dist4.h>
#include <gandalf/vision/canny_edge.h>
#include <gandalf/vision/convolve1D.h>
#include <gandalf/vision/convolve2D.h>
#include <gandalf/vision/corner_disp.h>
#include <gandalf/vision/corner_feature.h>
#include <gandalf/vision/edge_disp.h>
#include <gandalf/vision/edge_feature.h>
#include <gandalf/vision/essential.h>
#include <gandalf/vision/euclid3D.h>
#include <gandalf/vision/fast_hough_transform.h>
#include <gandalf/vision/fundamental.h>
#include <gandalf/vision/harris_corner.h>
#include <gandalf/vision/homog33_fit.h>
#include <gandalf/vision/homog34_fit.h>
#include <gandalf/vision/lev_marq.h>
#include <gandalf/vision/line_disp.h>
#include <gandalf/vision/line_feature.h>
#include <gandalf/vision/local_feature.h>
#include <gandalf/vision/mask1D.h>
#include <gandalf/vision/mask2D.h>
#include <gandalf/vision/modified_fht2D.h>
#include <gandalf/vision/orthog_line.h>
#include <gandalf/vision/rotate3D.h>
#include <gandalf/vision/segment_strings.h>
